@@ -86,6 +86,8 @@ class PrintLogHighlighter(RegexHighlighter):
         r" [0-9][0-9]:[0-9][0-9]:[0-9][0-9])",
         r"(?P<quoted>'[a-zA-Z0-9-._=;:\/\\\[\]{}+#@$£%\^&\*\(\)~`<>?]*')",
         r"(?P<ydid>ydid:[a-z]*:[0-9ABCDEF]*:[0-9abcdef-]*)",
+        r"(?P<ydid>ydid:[a-z]*:[0-9ABCDEF]*:[0-9abcdef-]*:[0-9]*)",
+        r"(?P<ydid>ydid:[a-z]*:[0-9ABCDEF]*:[0-9abcdef-]*:[0-9]*:[0-9]*)",
         r"(?P<url>(https?):((//)|(\\\\))+[\w\d:#@%/;$~_?\+-=\\\.&]*)",
     ] + HIGHLIGHTED_STATES
 
@@ -101,6 +103,8 @@ class PrintTableHighlighter(RegexHighlighter):
         rf"(?P<table_outline>[{table_outline_chars}]*)",
         rf"(?P<table_content>[^{table_outline_chars}]*)",
         r"(?P<ydid>ydid:[a-z]*:[0-9ABCDEF]*:[0-9abcdef-]*)",
+        r"(?P<ydid>ydid:[a-z]*:[0-9ABCDEF]*:[0-9abcdef-]*:[0-9]*)",
+        r"(?P<ydid>ydid:[a-z]*:[0-9ABCDEF]*:[0-9abcdef-]*:[0-9]*:[0-9]*)",
     ] + HIGHLIGHTED_STATES
 
 
@@ -144,7 +148,6 @@ def print_string(msg: str = "", no_fill: bool = False) -> str:
 def print_simple(
     log_message: str = "",
     override_quiet: bool = False,
-    no_fill: bool = False,
 ):
     """
     Simple print function without timestamp.
@@ -1154,6 +1157,8 @@ STATUS_COUNTS_INSTANCES = [
 STATUS_COUNTS_WORKERS = [
     StatusCount("DOING_TASK", True),
     StatusCount("SLEEPING", True),
+    StatusCount("STOPPED", True),
+    StatusCount("STARTING", True),
     StatusCount("LATE"),
     StatusCount("FOUND"),
     StatusCount("LOST"),
